@@ -1,8 +1,8 @@
 import Fau_tools.torch_tools
-from .Fau import *
+from .utility import *
 
 # __all__ = ["calc_time"]
 
 
 # import Fau_tools.torch_tools   is for calling function in [Fau_tools.torch_tools.xxx()].
-# from .Fau import *   is for calling function in Fau model in [Fau_tools.xxx()]
+# from .utility import *   is for calling function in utility model in [Fau_tools.xxx()]
